@@ -1,6 +1,14 @@
-"""This module provides the ConstantDomainExpression class to represent constant expressions.
+"""This module provides the ConstantDomainExpression class to
+represent constant expressions.
 
-Copyright 2014--2021 Michael Hayes, UCECE
+Note there are two types:
+1. ConstantTimeDomainExpression for signals
+2. ConstantFrequencyResponseDomainExpression for transfer functions and immitances.
+
+Note, impedance(3)(s) gives 3 but voltage(3)(s) gives 3 / s.
+Similarly, voltage(3)(t) gives 3 but impedance(3)(t) gives 3 * delta)(t)
+
+Copyright 2014--2022 Michael Hayes, UCECE
 
 """
 
@@ -28,7 +36,7 @@ class ConstantDomainExpression(ConstantDomain, Expr):
         for symbol in ('s', 'omega', 't', 'f'):
             if symbol in symbols:
                 raise ValueError(
-                    'constant expression %s cannot depend on %s' % (val, symbol))
+                    'Constant expression %s cannot depend on %s' % (val, symbol))
 
         assumptions['dc'] = True
         super(ConstantDomainExpression, self).__init__(val, **assumptions)
@@ -50,21 +58,47 @@ class ConstantDomainExpression(ConstantDomain, Expr):
 
         return self.time().angular_fourier()
 
+    def frequency_response(self):
+        """Convert to  frequency response domain representation."""
+
+        return self.change(self, domain='angular frequency response')
+
+    def angular_frequency_response(self):
+        """Convert to angular frequency response domain representation."""
+
+        return self.change(self, domain='angular frequency response')
+
     def canonical(self, factor_const=True):
         # Minor optimisation
         return self
 
-    def phasor(self, **assumptions):
+    def phasor(self, omega=None, **assumptions):
 
-        return self.laplace(**assumptions).phasor(**assumptions)
+        from .phasor import PhasorDomainExpression
+
+        return PhasorDomainExpression.from_constant(self, omega=omega,
+                                                    **assumptions)
+
+    def phasor_ratio(self, omega=None, **assumptions):
+
+        return self.as_laplace(**assumptions).phasor_ratio(omega=omega,
+                                                           **assumptions)
 
     def time(self, **assumptions):
+        """Convert to time domain representation."""
+
         return self.change(self, domain='time', **assumptions)
 
-    def laplace(self):
+    def laplace(self, **assumptions):
         """Convert to Laplace domain representation."""
 
-        return self.time().laplace()
+        return self.time().laplace(**assumptions)
+        # return self.change(self, domain='laplace', **assumptions)
+
+    def as_laplace(self, **assumptions):
+        """Convert to Laplace domain representation."""
+
+        return self.change(self, domain='laplace', **assumptions)
 
     def response(self, xvector, tvector):
         """Evaluate response to input signal `xvector` at times
@@ -76,23 +110,46 @@ class ConstantDomainExpression(ConstantDomain, Expr):
 
 
 class ConstantTimeDomainExpression(ConstantDomainExpression):
+    """This represents constant voltage, current, voltage-squared, and
+    current-squared signals.
+
+    Note, impedance(3)(s) gives 3 but voltage(3)(s) gives 3 / s.
+
+    """
 
     def _class_by_quantity(self, quantity, domain=None):
 
-        if quantity == 'undefined':
+        if quantity == 'undefined' and domain is None:
             return ConstantTimeDomainExpression
 
         return super(ConstantTimeDomainExpression, self)._class_by_quantity(quantity, domain)
 
+    def phasor_ratio(self, omega=None, **assumptions):
 
-class ConstantFrequencyDomainExpression(ConstantDomainExpression):
+        raise ValueError(
+            'Cannot convert %s(%s) to phasor_ratio' %
+            (self.__class__.__name__, self))
+
+
+class ConstantFrequencyResponseDomainExpression(ConstantDomainExpression):
+    """This represents constant impedance, admittance, and transfer
+    functions.
+
+    Note, impedance(3)(s) gives 3 but voltage(3)(s) gives 3 / s.
+    """
 
     def _class_by_quantity(self, quantity, domain=None):
 
-        if quantity == 'undefined':
-            return ConstantFrequencyDomainExpression
+        if quantity == 'undefined' and domain is None:
+            return ConstantFrequencyResponseDomainExpression
 
-        return super(ConstantFrequencyDomainExpression, self)._class_by_quantity(quantity, domain)
+        return super(ConstantFrequencyResponseDomainExpression, self)._class_by_quantity(quantity, domain)
+
+    def phasor(self, omega=None, **assumptions):
+
+        raise ValueError(
+            'Cannot convert %s(%s) to phasor' %
+            (self.__class__.__name__, self))
 
     def laplace(self, **assumptions):
         return self.change(self, domain='laplace', **assumptions)
@@ -103,7 +160,7 @@ class ConstantFrequencyDomainExpression(ConstantDomainExpression):
         return self.laplace(**assumptions).time(**assumptions)
 
 
-def cexpr(arg, **assumptions):
+def cexpr(arg, frequency=False, **assumptions):
     """Create Lcapy constant expression from `arg`.
 
     By default, `arg` is assumed to be positive.  If symbols in the
@@ -116,6 +173,10 @@ def cexpr(arg, **assumptions):
         quantity = 'undefined'
 
     if quantity == 'undefined':
+
+        if frequency:
+            return ConstantFrequencyResponseDomainExpression(arg, **assumptions)
+
         # Sit on the fence rather than choosing ConstantTimeDomainExpression
         return ConstantDomainExpression(arg, **assumptions)
 
@@ -124,5 +185,7 @@ def cexpr(arg, **assumptions):
 
 from .expressionclasses import expressionclasses  # nopep8
 
-expressionclasses.register('constant', ConstantTimeDomainExpression, ConstantFrequencyDomainExpression,
-                           ('voltage', 'current', 'voltagesquared', 'currentsquared', 'undefined'))
+expressionclasses.register('constant', ConstantTimeDomainExpression,
+                           ConstantFrequencyResponseDomainExpression,
+                           ('voltage', 'current', 'voltagesquared',
+                            'currentsquared', 'undefined'))
