@@ -5,6 +5,7 @@ Copyright 2021--2022 Michael Hayes, UCECE
 """
 
 from .expr import expr, equation, ExprTuple
+from .functions import Function
 from .nexpr import DiscreteTimeDomainExpression
 from .differenceequation import DifferenceEquation
 from .discretetime import n, z, seq
@@ -19,7 +20,14 @@ class DLTIFilter(object):
     def __init__(self, b, a):
         """Create discrete-time filter where `b` is a list or array of
         numerator coefficients and `a` is a list or array of
-        denominator coefficients."""
+        denominator coefficients.
+
+        Note, a recursive (IIR) filter with more than 3 coefficients
+        for `a` is sensitive to truncation of the cofficients and can
+        easily become unstable.  It is better to use a sequence
+        of biquadratic filters.
+
+        """
 
         if not isiterable(b):
             b = (b, )
@@ -92,21 +100,27 @@ class DLTIFilter(object):
         rhs = 0 * n
 
         for m, bn in enumerate(self.b):
-            rhs += bn * expr('%s(n - %d)' % (inputsym, m))
+            rhs += bn * Function(inputsym)(n - m)
 
         for m, an in enumerate(self.a[1:]):
-            rhs -= an * expr('%s(n - %d)' % (outputsym, m + 1))
+            rhs -= an * Function(outputsym)(n - (m + 1))
 
         lhs = self.a[0] * expr('y(n)')
         return DifferenceEquation(lhs, rhs, inputsym, outputsym)
 
-    def zdomain_initial_response(self, ic):
+    def zdomain_initial_response(self, ic=None):
         """Return z-domain response due to initial conditions.
            ic : list with initial values y[-1], y[-2], ...
         """
 
         from .sym import zsym
 
+        if ic is None:
+            ic = ()
+
+        if not isiterable(ic):
+            ic = (ic, )
+
         Nl = len(self.a)
         if len(ic) != Nl:
             raise ValueError('Expecting %d initial conditions, got %d'
@@ -136,7 +150,7 @@ class DLTIFilter(object):
 
         return Yzi
 
-    def initial_response(self, ic):
+    def initial_response(self, ic=None):
         """Return response due to initial conditions in the time domain.
            ic : list with initial values y[-1], y[-2], ...
         """
@@ -251,3 +265,9 @@ class DLTIFilter(object):
         See also is_stable."""
 
         return self.transfer_function().is_marginally_stable
+
+    def inverse(self):
+        """Create inverse filter.  Note, in practice, an inverse filter
+        is sensitive to noise.  It is better to use a Wiener filter."""
+
+        return self.__class__(self.a, self.b)
