@@ -94,8 +94,18 @@ class FourierDomainExpression(FourierDomain, Expr):
         result = self.subs(Omega / (2 * pi * dt))
         return result
 
+    def frequency_response(self, **assumptions):
+        """Convert to frequency response domain."""
+
+        return self.laplace(**assumptions).frequency_response()
+
+    def angular_frequency_response(self, **assumptions):
+        """Convert to angular frequency response domain."""
+
+        return self.laplace(**assumptions).angular_frequency_response()
+
     def laplace(self, **assumptions):
-        """Determine one-side Laplace transform with 0- as the lower limit."""
+        """Determine one-sided Laplace transform with 0- as the lower limit."""
 
         result = self.time(**assumptions).laplace()
         return result
