@@ -28,6 +28,7 @@ from .extrafunctions import rect, sincn, sincu, trap, tri
 
 __all__ = ('FT', 'IFT')
 
+
 class FourierTransformer(BilateralForwardTransformer):
 
     name = 'Fourier transform'
@@ -47,7 +48,8 @@ class FourierTransformer(BilateralForwardTransformer):
             self.error()
 
         if isinstance(result, FourierTransform):
-            self.error()
+            self.error(
+                'Try using partfrac() for partial fraction expansion first.')
 
         return result
 
@@ -86,7 +88,7 @@ class FourierTransformer(BilateralForwardTransformer):
         const2, expr2 = factor_const(integrand, var)
 
         if (expr2.is_Function and
-            expr2.args[0] == t - var and limits[0] == 0 and limits[1] == oo):
+                expr2.args[0] == t - var and limits[0] == 0 and limits[1] == oo):
             return const2 * self.term(expr2.subs(t - var, t), t, f) / f
 
         # Look for convolution integral
@@ -95,7 +97,7 @@ class FourierTransformer(BilateralForwardTransformer):
             self.error('Need indefinite limits')
 
         if ((len(expr.args) != 2) or not expr2.is_Mul or
-            not expr2.args[0].is_Function or not expr2.args[1].is_Function):
+                not expr2.args[0].is_Function or not expr2.args[1].is_Function):
             self.error('Need integral of product of two functions')
 
         f1 = expr2.args[0]
@@ -191,7 +193,7 @@ class FourierTransformer(BilateralForwardTransformer):
             if not factor.has(t):
                 const1 *= factor
             else:
-                if factor.is_Function and factor.func == exp:
+                if factor.is_Function and factor.func == exp and factor.args[0].has(I):
                     exps *= factor
                 else:
                     other *= factor
@@ -214,6 +216,9 @@ class FourierTransformer(BilateralForwardTransformer):
                 return -const1 * I * pi * sign(sf)
             elif other == 1 / t**2:
                 return -const1 * 2 * pi**2 * sf * sign(sf)
+            elif False and other == exp(t):
+                # SymPy does not like Dirac Delta of a complex argument.
+                return DiracDelta(sf + I / (2 * pi))
             elif other.is_Function and other.func == Heaviside and other.args[0] == t:
                 return (const1 / (I * 2 * pi * sf) + const1 * DiracDelta(sf) / 2)
             elif other == Heaviside(t) * t:
@@ -224,6 +229,18 @@ class FourierTransformer(BilateralForwardTransformer):
                   other.args[1].func == Heaviside and other.args[1].args[0] == t):
                 e = exp(I * 2 * pi * sf)
                 return I * DiracDelta(sf, 1) / (4 * pi) * e - 1 / (4 * pi**2 * f**2) * e
+            # exp(c1 * t + c0) * u(t)
+            elif (other.is_Mul and len(other.args) == 2 and
+                  other.args[1].is_Function and other.args[1].func == exp and
+                  other.args[1].args[0].is_polynomial(t) and
+                  other.args[1].args[0].as_poly(t).is_linear and
+                  other.args[0].is_Function and
+                  other.args[0].func == Heaviside and
+                  other.args[0].args[0] == t):
+                foo = other.args[1].args[0]
+                c0 = foo.coeff(t, 0)
+                c1 = foo.coeff(t, 1)
+                return const1 * exp(c0) / (I * 2 * pi * sf - c1)
             elif other.is_Function and other.func == sincn and other.args[0] == t:
                 return const1 * rect(f)
             elif other.is_Function and other.func == sincu and other.args[0] == t:
@@ -255,15 +272,16 @@ class FourierTransformer(BilateralForwardTransformer):
             #     if a != 0:
             #         return const1 * const2 * f * exp(-b * 2 *pi * f / a) * sign(f) / (2 * pi)
 
-            # Sympy incorrectly gives exp(-a * t) instead of exp(-a * t) *
-            # Heaviside(t)
+            # Sympy incorrectly gives exp(-a * t) instead of exp(-a * t) * Heaviside(t)
             elif other.is_Pow and other.args[1] == -1 and other.args[0].has(t):
                 foo = other.args[0]
-                if foo.is_Add:
-                    bar = foo.args[1] / t
-                    if not bar.has(t) and bar.has(I):
-                        a = -(foo.args[0] * 2 * pi * I) / bar
-                        return const1 * exp(-a * sf) * Heaviside(sf * sign(a))
+
+                if (foo.is_polynomial(t) and foo.as_poly(t).is_linear and
+                        foo.is_complex):
+                    c0 = foo.coeff(t, 0)
+                    c1 = foo.coeff(t, 1)
+                    s = (2 * pi * I) / c1
+                    return const1 * s * exp(c0 * sf * s) * Heaviside(-sf)
                 elif foo.is_Function and foo.func == cosh and foo.args[0] == t:
                     return const * pi / cosh(pi**2 * sf)
                 elif foo.is_Function and foo.func == sinh and foo.args[0] == t:
