@@ -106,9 +106,11 @@ class Cpt(ImmittanceMixin):
                 newclass = getattr(lcapy.twoport, classname)
             except:
                 self._cpt = lcapy.oneport.Dummy()
+                self.check()
                 return
 
         self._cpt = newclass(*args)
+        self.check()
 
     def __repr__(self):
         return self.__str__()
@@ -121,6 +123,9 @@ class Cpt(ImmittanceMixin):
     def cpt(self):
         return self._cpt
 
+    def check(self):
+        pass
+
     def _stamp(self, mna):
         raise NotImplementedError('stamp method not implemented for %s' % self)
 
@@ -1028,6 +1033,12 @@ class VCVS(DependentSource):
 
     need_branch_current = True
 
+    def check(self):
+
+        n1, n2, n3, n4 = self.nodenames
+        if n1 == n3 and n2 == n4:
+            warn('VCVS output nodes and control nodes are the same for %s' % self)
+
     def _stamp(self, mna):
         n1, n2, n3, n4 = mna._cpt_node_indexes(self)
         m = mna._cpt_branch_index(self)
@@ -1157,6 +1168,11 @@ class CCCS(DependentSource):
 
     need_control_current = True
 
+    def check(self):
+
+        if self.args[0] == self.name:
+            warn('CCCS controlled by its own current for %s' % self)
+
     def _stamp(self, mna):
         n1, n2 = mna._cpt_node_indexes(self)
         m = mna._branch_index(self.args[0])
@@ -2086,6 +2102,7 @@ defcpt('ADC', Misc, 'ADC')
 defcpt('AM', W, 'Ammeter')
 
 defcpt('BAT', V, 'Battery')
+defcpt('BL', Misc, 'Block')
 
 defcpt('D', NonLinear, 'Diode')
 defcpt('DAC', Misc, 'DAC')
@@ -2126,6 +2143,9 @@ defcpt('Q', NonLinear, 'NPN transistor')
 defcpt('Qpnp', 'Q', 'PNP transistor')
 defcpt('Qnpn', 'Q', 'NPN transistor')
 
+# Could model if introduce MagneticCircuit class.
+defcpt('REL', Misc, 'Reluctance')
+
 defcpt('Sbox', Misc, 'Box shape')
 defcpt('Scircle', Misc, 'Circle shape')
 defcpt('Sellipse', Misc, 'Ellipse shape')
