@@ -7,6 +7,7 @@ Copyright 2020--2022 Michael Hayes, UCECE
 
 from .expr import expr
 from .analysis import Analysis
+from .components import Components
 from .mnacpts import Cpt
 from .impedance import impedance
 from .admittance import admittance
@@ -149,7 +150,7 @@ class NetlistMixin(object):
 
     @property
     def params(self):
-        """Return list of symbols used as arguments in the circuit."""
+        """Return list of symbols used as arguments in the netlist."""
 
         symbols = self.symbols
         params = []
@@ -161,7 +162,7 @@ class NetlistMixin(object):
 
     @property
     def symbols(self):
-        """Return dictionary of symbols defined in the circuit."""
+        """Return dictionary of symbols defined in the netlist."""
 
         return self.context.symbols
 
@@ -1690,234 +1691,9 @@ class NetlistMixin(object):
         names.discard(cpt)
         return list(names)
 
-    def _do_simplify_combine(self, string, subset, net,
-                             explain=False, add=False, series=False):
-
-        if explain:
-            print(string % subset)
-
-        subset_list = list(subset)
-
-        if add:
-            total = expr(0)
-            for name in subset_list:
-                total += expr(self.elements[name].cpt.args[0])
-        else:
-            total = expr(0)
-            for name in subset_list:
-                total += (1 / expr(self.elements[name].cpt.args[0]))
-            total = 1 / total
-
-        if explain:
-            print('%s combined value = %s' % (subset, total))
-
-        ic = None
-        name = subset_list[0]
-        elt = self.elements[name]
-        if elt.cpt.has_ic:
-            ic = expr(0)
-            for name1 in subset_list:
-                ic += expr(self.elements[name1].cpt.args[1])
-
-            if explain:
-                print('%s combined IC = %s' % (subset, ic))
-
-        newname = self.namer(name[0] + 't')
-        net1 = elt._new_value(total, ic)
-        parts = net1.split(' ', 1)
-        net1 = newname + ' ' + parts[1]
-
-        elt = self._parse(net1)
-
-        # Overwrite component with one having total value.  _fixup will
-        # fix element keys later on once all simplifications are performed.
-        net.elements[name] = elt
-
-        for name1 in subset_list[1:]:
-            # Replace with wire or open-circuit.
-            if series:
-                net1 = self.elements[name1]._netmake_W()
-            else:
-                net1 = self.elements[name1]._netmake_O()
-            # Remove component
-            elt = self._parse(net1)
-            net.elements[name1] = elt
-
-        return True
-
-    def _check_ic(self, subset):
-
-        subset = subset.copy()
-        name = subset.pop()
-        has_ic = self.elements[name].has_ic
-
-        okay = True
-        for name1 in subset:
-            if self.elements[name1].has_ic != has_ic:
-                warn('Incompatible initial conditions for %s and %s' %
-                     (name, name1))
-                okay = False
-        if not has_ic:
-            return okay
-        ic = self.elements[name].cpt.args[1]
-        for name1 in subset:
-            if self.elements[name1].cpt.args[1] != ic:
-                warn('Incompatible initial conditions for %s and %s' %
-                     (name, name1))
-                okay = False
-
-        return okay
-
-    def _fixup(self):
-        """Rename keys to fix things up for removed components."""
-
-        newelements = OrderedDict()
-        for k, v in self.elements.items():
-            newelements[v.name] = v
-        self._elements = newelements
-
-    def _simplify_combine_series(self, cptnames=None, explain=False):
-
-        net = self.copy()
-        changed = False
-
-        for aset in net.in_series():
-            subsets = net._find_combine_subsets(aset)
-            for k, subset in subsets.items():
-                if k == 'I':
-                    warn('Netlist has current sources in series: %s' % subset)
-                elif k in ('R', 'NR', 'L', 'V', 'Z'):
-                    if k == 'L' and not self._check_ic(subset):
-                        continue
-                    changed |= self._do_simplify_combine('Can add in series: %s',
-                                                         subset, net, explain, True, True)
-                elif k in ('C', 'Y'):
-                    changed |= self._do_simplify_combine('Can combine in series: %s',
-                                                         subset, net, explain, False, True)
-                else:
-                    raise RuntimeError('Internal error')
-
-        if changed:
-            net._fixup()
-
-        return net, changed
-
-    def _simplify_combine_parallel(self, cptnames=None, explain=False):
-
-        net = self.copy()
-        changed = False
-
-        for aset in net.in_parallel():
-            subsets = net._find_combine_subsets(aset)
-            for k, subset in subsets.items():
-                if k == 'V':
-                    warn('Netlist has voltage sources in parallel: %s' % subset)
-                elif k in ('R', 'NR', 'L', 'Z'):
-                    changed |= self._do_simplify_combine('Can combine in parallel: %s',
-                                                         subset, net, explain, False, False)
-                elif k in ('C', 'Y', 'I'):
-                    if k == 'C' and not self._check_ic(subset):
-                        continue
-                    changed |= self._do_simplify_combine('Can add in parallel: %s',
-                                                         subset, net, explain, True, False)
-                else:
-                    raise RuntimeError('Internal error')
-
-        if changed:
-            # TODO, remove dangling wires connected to the removed components.
-            net._fixup()
-
-        return net, changed
-
-    def _simplify_redundant_series(self, cptnames=None, explain=False):
-
-        net = self.copy()
-        changed = False
-
-        for aset in net.in_series():
-            Iname = None
-            for name in aset:
-                cpt = self._elements[name]
-                if cpt.type == 'I':
-                    Iname = name
-                    break
-            if Iname is not None:
-                for name in aset:
-                    cpt = self._elements[name]
-                    if cpt.type != 'I':
-                        warn('Have redundant %s in series with %s' %
-                             (name, Iname))
-
-        return net, False
-
-    def _simplify_redundant_parallel(self, cptnames=None, explain=False):
-
-        net = self.copy()
-        changed = False
-
-        for aset in net.in_parallel():
-            Vname = None
-            for name in aset:
-                cpt = self._elements[name]
-                if cpt.type == 'V':
-                    Vname = name
-                    break
-            if Vname is not None:
-                for name in aset:
-                    cpt = self._elements[name]
-                    if cpt.type != 'V':
-                        warn('Have redundant %s in parallel with %s' %
-                             (name, Vname))
-
-        return net, False
-
-    def _simplify_series(self, cptnames=None, explain=False):
-
-        net, changed = self._simplify_redundant_series(cptnames, explain)
-        net, changed2 = net._simplify_combine_series(cptnames, explain)
-        return net, changed or changed2
-
-    def _simplify_parallel(self, cptnames=None, explain=False):
-
-        net, changed = self._simplify_redundant_parallel(cptnames, explain)
-        net, changed2 = net._simplify_combine_parallel(cptnames, explain)
-        return net, changed or changed2
-
-    def simplify_series(self, cptnames=None, explain=False, modify=True):
-
-        net, changed = self._simplify_series(cptnames, explain)
-        if not modify:
-            return self
-        return net
-
-    def simplify_parallel(self, cptnames=None, explain=False, modify=True):
-
-        net, changed = self._simplify_parallel(cptnames, explain)
-        if not modify:
-            return self
-        return net
-
-    def simplify(self, cptnames=None, passes=0, series=True,
-                 parallel=True, explain=False, modify=True):
-
-        # Perhaps use num cpts?
-        if passes == 0:
-            passes = 10
-
-        net = self
-        for m in range(passes):
-
-            net, series_changed = net._simplify_series(cptnames, explain)
-            net, parallel_changed = net._simplify_parallel(cptnames, explain)
-            if not series_changed and not parallel_changed:
-                break
-        if not modify:
-            return self
-
-        return net
-
     def check(self):
-        """Check if network contains a loop of voltage sources or a cut set of current sources."""
+        """Check if network contains a loop of voltage sources or a cut set of
+        current sources."""
 
         return self.simplify(explain=True, modify=False)
 
@@ -2071,8 +1847,7 @@ class NetlistMixin(object):
         return new
 
     def pre_initial_model(self):
-        """Generate circuit model for determining the pre-initial
-        conditions."""
+        """Generate model for determining the pre-initial conditions."""
 
         new = self._new()
 
@@ -2278,7 +2053,7 @@ class NetlistMixin(object):
     @property
     def is_IVP(self):
         """Return True for an initial value problem.  This is True if any
-        component that allows initial conditions has them explicitly
+        component (L, C) that allows initial conditions has them explicitly
         defined.
 
         """
@@ -2293,6 +2068,12 @@ class NetlistMixin(object):
         ).warn()
         return self.is_IVP
 
+    @property
+    def is_passive(self):
+        """Return True for a passive network, i.e., there are no sources."""
+
+        return self.sources == {}
+
     @property
     def is_switching(self):
         """Return True for a switching circuit."""
@@ -2327,31 +2108,31 @@ class NetlistMixin(object):
     def transformers(self):
         """Return dictionary of transformers."""
 
-        return self.analysis.transformers
+        return self.components.transformers
 
     @property
     def capacitors(self):
         """Return dictionary of capacitors."""
 
-        return self.analysis.capacitors
+        return self.components.capacitors
 
     @property
     def inductors(self):
         """Return dictionary of inductors."""
 
-        return self.analysis.inductors
+        return self.components.inductors
 
     @property
     def voltage_sources(self):
         """Return dictionary of voltage_sources."""
 
-        return self.analysis.voltage_sources
+        return self.components.voltage_sources
 
     @property
     def current_sources(self):
         """Return dictionary of current_sources."""
 
-        return self.analysis.current_sources
+        return self.components.current_sources
 
     @property
     def ics(self):
@@ -2430,7 +2211,15 @@ class NetlistMixin(object):
 
     def analyse(self):
 
-        return Analysis(self)
+        return Analysis(self, self.components)
+
+    @property
+    def components(self):
+
+        if not hasattr(self, '_components'):
+            self._components = Components(self)
+
+        return self._components
 
     def describe(self):
         """Print a message describing how circuit is solved."""
