@@ -1,5 +1,5 @@
-"""This module provides the PhasorDomain classes to represent phasors
- for AC analysis.
+"""This module provides the PhasorDomain and PhasorRatioDomain classes
+ to represent phasors and ratios of phasors for AC analysis.
 
 A phasor represents the amplitude and phase for a single sinusoid.  By
 default the angular frequency is omega_0 but it can be any number or
@@ -13,36 +13,38 @@ implicit frequency.  The amplitude and phase are usually functions of
 frequency.  A phasor is useful to describe an AC voltage or current
 signal.
 
-A ratio of two phasors (of the same frequency) is no longer a
-time-domain signal but a frequency domain quantity.  The frequency
-dependence is explicit.  A phasor ratio is useful to describe an
-immittance or transfer function.  These are frequency domain concepts.
-A phasor ratio can be inferred from the Laplace domain by substituting
-jomega (or jw) for s, where omega is the angular frequency of the phasor.
-
 Lcapy considers V(jw) or I(jw) a generic phasor but V(3j) or I(3j) a
 specific phasor.  Similarly, X(jw) is a generic phasor ratio and X(3j)
 is a specific phasor ratio, where X denotes an immittance or transfer
 function.
 
-Copyright 2014--2021 Michael Hayes, UCECE
+A ratio of two phasors (of the same frequency) is not a phasor.  The
+ratio of two generic phasors is a frequency domain quantity.  The
+frequency dependence is explicit.  A phasor ratio is useful to
+describe an immittance or transfer function.  These are frequency
+domain concepts.  A phasor ratio can be inferred from the Laplace
+domain by substituting jomega (or jw) for s, where omega is the
+angular frequency of the phasor.
+
+Copyright 2014--2022 Michael Hayes, UCECE
 
 """
 
 from __future__ import division
 from .expressionclasses import expressionclasses
 from .acdc import ACChecker
-from .domains import PhasorTimeDomain, PhasorFrequencyDomain
-from .sym import j, omegasym
+from .domains import PhasorDomain, PhasorRatioDomain
+from .sym import j, omegasym, fsym, pi
 from .expr import expr
 from .functions import sin, cos, exp, sqrt
 from .expr import Expr
 from .omegaexpr import omega
+from .units import u as uu
 from sympy import Expr as symExpr
 from warnings import warn
 
 
-__all__ = ('phasor', )
+__all__ = ('phasor', 'phasor_ratio')
 
 # The phasor domain is different from the Fourier and Laplace domain
 # since there is an implicit angular frequency.  This is only needed
@@ -69,8 +71,6 @@ class PhasorExpression(Expr):
     def var(self):
         """Return underlying variable as sympy expression."""
 
-        from .sym import fsym, omegasym, pi
-
         if self.omega == omegasym:
             return omegasym
 
@@ -97,9 +97,6 @@ class PhasorExpression(Expr):
         if self.domain != x.domain:
             return False
 
-        if False and self.is_phasor_time_domain ^ x.is_phasor_time_domain:
-            return False
-
         if not hasattr(x, 'omega'):
             return True
 
@@ -122,14 +119,19 @@ class PhasorExpression(Expr):
 
     def _mul_compatible_domains(self, x):
 
-        from .sym import pi
-
         if (self.is_constant_domain or x.is_constant_domain):
             return True
 
         if self._compatible_phasors(x):
             return True
 
+        if (self.is_phasor_ratio_domain and x.is_phasor_domain and
+                self.omega == x.omega):
+            return True
+        if (self.is_phasor_domain and x.is_phasor_ratio_domain and
+                self.omega == x.omega):
+            return True
+
         # Allow phasor(x) * omega, etc.
         if (self.is_phasor_domain and x.is_angular_fourier_domain and
                 self.omega == x.var):
@@ -138,13 +140,18 @@ class PhasorExpression(Expr):
                 self.omega == 2 * pi * x.var):
             return True
 
+        if (self.is_phasor_ratio_domain and x.is_angular_fourier_domain and
+                self.omega == x.var):
+            return True
+        if (self.is_phasor_ratio_domain and x.is_fourier_domain and
+                self.omega == 2 * pi * x.var):
+            return True
+
         return False
 
     def subs(self, *args, safe=False, **kwargs):
         """Substitute variables in expression, see sympy.subs for usage."""
 
-        from .sym import fsym, pi
-
         # Handle omega -> 2 * pi * f conversions to Fourier domain.
         if len(args) == 1 and args[0] == 2 * pi * fsym:
             from .fexpr import FourierDomainExpression
@@ -163,12 +170,9 @@ Converting to Fourier domain via phasor domain may not give correct answer.   It
         return super(PhasorExpression, self).subs(*args, **kwargs)
 
 
-class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
+class PhasorDomainExpression(PhasorDomain, PhasorExpression):
     """This is a phasor domain base class for voltages and currents."""
 
-    is_phasor_domain = True
-    is_phasor_time_domain = True
-
     def __init__(self, val, **assumptions):
 
         if isinstance(val, PhasorExpression):
@@ -182,15 +186,25 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
         assumptions['ac'] = True
         super(PhasorExpression, self).__init__(val, **assumptions)
 
+    def _div_domain(self, x):
+
+        if x.is_phasor_domain:
+            return 'phasor ratio'
+
+        return self.domain
+
     def _class_by_quantity(self, quantity, domain=None):
 
         if quantity == 'undefined':
-            return PhasorTimeDomainExpression
+            if domain == 'phasor ratio':
+                return PhasorRatioDomainExpression
+            else:
+                return PhasorDomainExpression
 
-        return super(PhasorTimeDomainExpression, self)._class_by_quantity(quantity, domain)
+        return super(PhasorDomainExpression, self)._class_by_quantity(quantity, domain)
 
     def as_expr(self):
-        return PhasorTimeDomainExpression(self)
+        return PhasorDomainExpression(self)
 
     @classmethod
     def from_time(cls, expr, omega=None, **assumptions):
@@ -225,6 +239,11 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
 
         return cls.change(expr, result, domain='phasor', **assumptions)
 
+    @classmethod
+    def from_constant(cls, expr, omega=None, **assumptions):
+
+        return cls(expr, omega=omega)
+
     def time(self, **assumptions):
         """Convert to time domain representation."""
         from .symbols import t
@@ -268,11 +287,11 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
         return plot_phasor(self, **kwargs)
 
 
-class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
+class PhasorRatioDomainExpression(PhasorRatioDomain, PhasorExpression):
     """This represents the ratio of two-phasors; for example
     an impedance, an admittance, or a transfer function."""
 
-    is_phasor_frequency_domain = True
+    is_phasor_ratio_domain = True
     is_transform_domain = True
 
     def __init__(self, val, **assumptions):
@@ -290,12 +309,19 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
 
         super(PhasorExpression, self).__init__(val, **ass)
 
+    def _mul_domain(self, x):
+
+        if x.is_phasor_domain:
+            return 'phasor'
+
+        return self.domain
+
     def _class_by_quantity(self, quantity, domain=None):
 
         if quantity == 'undefined':
-            return PhasorFrequencyDomainExpression
+            return PhasorRatioDomainExpression
 
-        return super(PhasorFrequencyDomainExpression, self)._class_by_quantity(quantity, domain)
+        return super(PhasorRatioDomainExpression, self)._class_by_quantity(quantity, domain)
 
     @classmethod
     def from_laplace(cls, expr, **assumptions):
@@ -321,9 +347,9 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
 
         quantity = expr.quantity
         if quantity == 'undefined':
-            cls = PhasorFrequencyDomainExpression
+            cls = PhasorRatioDomainExpression
         else:
-            cls = expr._class_by_domain('phasor')
+            cls = expr._class_by_domain('phasor ratio')
 
         ret = cls(result2, omega=omega, **ass)
         return ret
@@ -333,8 +359,8 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
 
         from .sym import fsym
 
-        # TODO, remove this say by having PhasorFrequencyDomainExpression
-        # and PhasorAngularFrequencyDomainExpression classes.
+        # TODO, remove this say by having PhasorRatioDomainExpression
+        # and PhasorAngularFrequencyResponseDomainExpression classes.
 
         if self.var == fsym:
             return 'Frequency'
@@ -347,8 +373,8 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         from .sym import fsym
         from .units import u as uu
 
-        # TODO, remove this say by having PhasorFrequencyDomainExpression
-        # and PhasorAngularFrequencyDomainExpression classes.
+        # TODO, remove this say by having PhasorRatioDomainExpression
+        # and PhasorAngularFrequencyResponseDomainExpression classes.
 
         if self.var == fsym:
             return uu.Hz
@@ -369,8 +395,14 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         ass = self.assumptions.copy()
         assumptions = ass.merge(**assumptions)
 
-        omega = self.omega
-        result = self.expr.replace(omega, ssym / j)
+        if self.var == omegasym:
+            result = self.expr.replace(omegasym, ssym / j)
+        elif self.var == fsym:
+            result = self.expr.replace(fsym, ssym / (j * 2 * pi))
+        else:
+            raise ValueError(
+                'Cannot convert PhasorRatioDomain to LaplaceDomain for variable %s' % self.var)
+
         return LaplaceDomainExpression(result, **assumptions).as_quantity(self.quantity)
 
     def angular_fourier(self, **assumptions):
@@ -388,7 +420,7 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
         return self.time().fourier()
 
     def as_expr(self):
-        return PhasorFrequencyDomainExpression(self)
+        return PhasorRatioDomainExpression(self)
 
     def plot(self, fvector=None, **kwargs):
         """Plot frequency response.
@@ -444,16 +476,35 @@ def phasor(arg, omega=None, **assumptions):
 
     if arg.is_time_domain:
         # Expecting AC signal.
-        return PhasorTimeDomainExpression.from_time(arg, omega=omega, **assumptions)
+        return PhasorDomainExpression.from_time(arg, omega=omega, **assumptions)
     else:
         # Expecting phasor (complex amplitude)
-        return PhasorTimeDomainExpression(arg, omega=omega, **assumptions)
+        return PhasorDomainExpression(arg, omega=omega, **assumptions)
 
 
-expressionclasses.register('phasor', PhasorTimeDomainExpression,
-                           PhasorFrequencyDomainExpression,
+def phasor_ratio(arg, omega=None, **assumptions):
+    """Create phasor ratio.
+
+    If arg is a constant C, the phasor ratio C is created with omega as the
+    angular frequency (this defaults to 'omega' if not specified).
+
+    """
+
+    arg = expr(arg)
+
+    return PhasorRatioDomainExpression(arg, omega=omega, **assumptions)
+
+
+expressionclasses.register('phasor', PhasorDomainExpression,
+                           None,
                            ('voltage', 'current',
-                            'voltagesquared', 'currentsquared', 'undefined'))
+                            'voltagesquared', 'currentsquared', 'power',
+                            'undefined'))
+
+# Handle voltage, current frequency response as phasor ratios
+# so that voltage(1 / (s + 2)).subs(jw) works.
+# Probably should add a frequency response domain.
+expressionclasses.register('phasor ratio', PhasorRatioDomainExpression)
 
 from .texpr import TimeDomainExpression  # nopep8
 from .expr import Expr  # nopep8
