@@ -113,7 +113,16 @@ class Superposition(SuperpositionDomain, ExprDict):
         is not defined, jupyter falls back on _repr__pretty_ which
         outputs unicode."""
 
-        return '$$' + latex(self._representation()) + '$$'
+        s = latex(self._representation(), mode='plain')
+        return "$$%s$$" % s
+
+    def _repr_png_(self):
+
+        return None
+
+    def _repr_svg_(self):
+
+        return None
 
     def pprint(self):
         """Pretty print"""
@@ -534,7 +543,7 @@ class Superposition(SuperpositionDomain, ExprDict):
         return str(self.time())
 
     def _kind(self, value):
-        if isinstance(value, PhasorTimeDomainExpression):
+        if isinstance(value, PhasorDomainExpression):
             # Use angular frequency for key.  This can be a nuisance
             # for numerical values since cannot use x.3 syntax
             # say for an angular frequency of 3.
@@ -807,11 +816,10 @@ from .fexpr import FourierDomainExpression  # nopep8
 from .sexpr import LaplaceDomainExpression  # nopep8
 from .texpr import TimeDomainExpression  # nopep8
 from .noiseexpr import NoiseExpression  # nopep8
-from .phasor import PhasorTimeDomainExpression  # nopep8
+from .phasor import PhasorDomainExpression  # nopep8
 from .omegaexpr import AngularFourierDomainExpression  # nopep8
 from .symbols import s, omega  # nopep8
 
-
 # See expr.py
 
 try:
