@@ -236,7 +236,31 @@ class LatexRunner(object):
                     print('Removing: %s' % filename)
                 remove(filename)
 
-    def circuitikz_version(self):
+    def extract_circuitikz_version(self, tex_filename):
+
+        log_filename = tex_filename.replace('.tex', '.log')
+
+        with open(log_filename, 'rt') as logfile:
+            lines = logfile.readlines()
+
+        date = None
+        version = None
+        for m, line in enumerate(lines):
+            if line.startswith('Package: circuitikzgit'):
+                match = re.search(r'circuitikzgit ([0-9/]+)', line)
+                date = match.group(1)
+                # There is an annoying newline in the middle of the word version
+                version = lines[m + 1].strip('ion').strip()
+                break
+            if line.startswith('Package: circuitikz'):
+                match = re.search(r'circuitikz ([0-9/]+)', line)
+                date = match.group(1)
+                version = lines[m + 1].strip()
+                break
+
+        return date, version
+
+    def find_circuitikz_version(self):
 
         content = r"""
         \documentclass[a4paper]{standalone}
@@ -247,20 +271,9 @@ class LatexRunner(object):
         tex_filename = tmpfilename('.tex')
         open(tex_filename, 'w').write(content)
 
-        log_filename = tex_filename.replace('.tex', '.log')
         self.run(tex_filename)
 
-        with open(log_filename, 'rt') as logfile:
-            lines = logfile.readlines()
-
-        date = None
-        version = None
-        for m, line in enumerate(lines):
-            if line.startswith('Package: circuitikz'):
-                match = re.search(r'circuitikz ([0-9/]+)', line)
-                date = match.group(1)
-                version = lines[m + 1].strip()
-                break
+        date, version = self.extract_circuitikz_version(tex_filename)
 
         self.cleanup(tex_filename)
         return date, version
