@@ -1,5 +1,5 @@
 from lcapy import *
-from lcapy.phasor import PhasorFrequencyDomainExpression
+from lcapy.phasor import PhasorRatioDomainExpression
 import unittest
 
 
@@ -59,16 +59,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(q, r, 'phasor(2) * omega')
 
-    def test_phasor_omega_transform(self):
-
-        from lcapy.sym import omegasym
-
-        H = 1 / s
-        P = H(jw)
-
-        self.assertEqual(type(P), PhasorFrequencyDomainExpression, 'H(jw)')
-        self.assertEqual(P.var, omegasym, 'P.var')
-
     def test_phasor_f_transform(self):
 
         from lcapy.sym import fsym
@@ -76,7 +66,7 @@ class LcapyTester(unittest.TestCase):
         H = 1 / s
         P = H(j * 2 * pi * f)
 
-        self.assertEqual(type(P), PhasorFrequencyDomainExpression,
+        self.assertEqual(type(P), PhasorRatioDomainExpression,
                          'H(j * 2 * pi * f)')
 
         self.assertEqual(P.var, fsym, 'P.var')
@@ -90,12 +80,19 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(Z1.omega, 2, 'Z1.omega')
         self.assertEqual(Z1.is_impedance, True, 'Z1.is_impedance')
-        self.assertEqual(Z1.is_phasor_frequency_domain, True,
-                         'Z1.is_phasor_frequency_domain')
+        self.assertEqual(Z1.is_phasor_ratio_domain, True,
+                         'Z1.is_phasor_ratio_domain')
 
         V2 = Z1 * I1
 
         self.assertEqual(V2.omega, 2, 'V2.omega')
         self.assertEqual(V2.is_voltage, True, 'V2.is_voltage')
-        self.assertEqual(V2.is_phasor_time_domain, True,
-                         'V2.is_phasor_time_domain')
+        self.assertEqual(V2.is_phasor_domain, True, 'V2.is_phasor_domain')
+
+    def test_phasor_omega_laplace(self):
+
+        self.assertEqual(jomega(s), s, 'jomega(s)')
+
+    def test_phasor_f_laplace(self):
+
+        self.assertEqual(j2pif(s), s, 'j2pif(s)')
