@@ -22,8 +22,8 @@ class LcapyTester(unittest.TestCase):
 \begin{tikzpicture}[scale=1.00, transform shape, /tikz/circuitikz/bipoles/length=1.50cm, american currents, american voltages, voltage dir=RP]
   \coordinate (1) at (0,0);
   \coordinate (2) at (2,0);
-  \coordinate (3) at (3,0);
-  \coordinate (0) at (5,0);
+  \coordinate (3) at (2.5,0);
+  \coordinate (0) at (4.5,0);
   \draw[] (1) to [R,l_=$1\,\mbox{$\Omega$}$,,,,n=R1] (2);
   \draw (1) node[ocirc] {};
   \draw[-, , ] (2) to (3);
@@ -85,8 +85,8 @@ C 1 3 3; right""")
 
         self.assertEqual(nodes['1'].pos.x, 0, '1 x')
         self.assertEqual(nodes['2'].pos.x, 2, '2 x')
-        self.assertEqual(nodes['3'].pos.x, 3, '3 x')
-        self.assertEqual(nodes['0'].pos.x, 5, '0 x')
+        self.assertEqual(nodes['3'].pos.x, 2.5, '3 x')
+        self.assertEqual(nodes['0'].pos.x, 4.5, '0 x')
 
     def test_network_node_positions2(self):
 
@@ -96,15 +96,15 @@ C 1 3 3; right""")
         nodes = sch.nodes
 
         self.assertEqual(nodes['1'].pos.x, 0, '1 x')
-        self.assertEqual(nodes['2'].pos.x, 1, '2 x')
-        self.assertEqual(nodes['3'].pos.x, 6, '3 x')
-        self.assertEqual(nodes['4'].pos.x, 1, '4 x')
-        self.assertEqual(nodes['5'].pos.x, 6, '5 x')
-        self.assertEqual(nodes['6'].pos.x, 3, '6 x')
-        self.assertEqual(nodes['7'].pos.x, 4, '7 x')
-        self.assertEqual(nodes['8'].pos.x, 1, '8 x')
-        self.assertEqual(nodes['9'].pos.x, 6, '9 x')
-        self.assertEqual(nodes['0'].pos.x, 7, '0 x')
+        self.assertEqual(nodes['2'].pos.x, 0.5, '2 x')
+        self.assertEqual(nodes['3'].pos.x, 5, '3 x')
+        self.assertEqual(nodes['4'].pos.x, 0.5, '4 x')
+        self.assertEqual(nodes['5'].pos.x, 5, '5 x')
+        self.assertEqual(nodes['6'].pos.x, 2.5, '6 x')
+        self.assertEqual(nodes['7'].pos.x, 3, '7 x')
+        self.assertEqual(nodes['8'].pos.x, 0.5, '8 x')
+        self.assertEqual(nodes['9'].pos.x, 5, '9 x')
+        self.assertEqual(nodes['0'].pos.x, 5.5, '0 x')
 
     def test_network_danglin3(self):
 
