@@ -51,6 +51,16 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         return x.is_constant_domain
 
+    def _mul_dubious(self, x):
+
+        # Allow rect(t) * rect(t) etc.
+        if not (self.is_signal or self.is_immittance or
+                x.is_signal or x.is_immittance):
+            return False
+
+        # Allow v*v.
+        return x.is_time_domain and not (self.is_signal and x.is_signal)
+
     def _div_compatible_domains(self, x):
 
         if self.domain == x.domain:
@@ -58,6 +68,11 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         return x.is_constant_domain
 
+    def _div_dubious(self, x):
+
+        # What about v * v / v ?
+        return x.is_time_domain
+
     @property
     def abs(self):
         """Return absolute value."""
@@ -108,9 +123,9 @@ class TimeDomainExpression(TimeDomain, Expr):
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
-        from .phasor import PhasorTimeDomainExpression
+        from .phasor import PhasorDomainExpression
 
-        return PhasorTimeDomainExpression.from_time(self, **assumptions)
+        return PhasorDomainExpression.from_time(self, **assumptions)
 
     def FT(self, var=None, evaluate=True, **assumptions):
         """Attempt Fourier transform.
@@ -165,6 +180,18 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         return self.FT(Omega, evaluate, **assumptions)
 
+    def frequency_response(self, **assumptions):
+        """Convert to frequency response domain.  Note, this is similar to the
+        Fourier domain but not always."""
+
+        return self.laplace(**assumptions).frequency_response()
+
+    def angular_frequency_response(self, **assumptions):
+        """Convert to angular frequency response domain.  Note, this is
+        similar to the angular Fourier domain but not always."""
+
+        return self.laplace(**assumptions).angular_frequency_response()
+
     def time(self, **assumptions):
         return self
 
@@ -272,6 +299,11 @@ class TimeDomainExpression(TimeDomain, Expr):
         H = Hc.discretize(method=method, alpha=alpha)
         return H.IZT()
 
+    def dlti_filter(self, method='bilinear'):
+        """Create DLTI filter using bilinear transform."""
+
+        return self.LT().dlti_filter(method)
+
     def zdomain(self, **assumptions):
 
         # Going via the Laplace domain will restrict result for n >= 0.
